@@ -39,6 +39,8 @@ namespace Tomboy
 
 			InsertText += TextInsertedEvent;
 			MarkSet += MarkSetEvent;
+			
+			TagApplied += OnTagApplied;
 
 			tags.TagChanged += OnTagChanged;
 
@@ -63,6 +65,10 @@ namespace Tomboy
 			Gtk.TextIter select_start, select_end;
 
 			if (GetSelectionBounds (out select_start, out select_end)) {
+				// Ignore the bullet character
+				if (FindDepthTag(ref select_start) != null)
+					select_start.LineOffset = 2;
+
 				if (select_start.BeginsTag (tag) || select_start.HasTag (tag))
 					RemoveTag (tag, select_start, select_end);
 				else
@@ -103,15 +109,48 @@ namespace Tomboy
 			}
 		}
 
+		public void OnTagApplied (object o, Gtk.TagAppliedArgs args)
+		{	
+			if (!(args.Tag is DepthNoteTag)) {
+				// Remove the tag from any bullets in the selection
+				Undoer.FreezeUndo ();
+				Gtk.TextIter iter;
+				for (int i = args.StartChar.Line; i <= args.EndChar.Line; i++) {
+					iter = GetIterAtLine(i);
+					
+					if (FindDepthTag (ref iter) != null) {
+						Gtk.TextIter next = iter;
+						next.ForwardChars (2);
+						RemoveTag (args.Tag, iter, next);
+					}
+				}
+				Undoer.ThawUndo ();
+			} else {
+				// Remove any existing tags when a depth tag is applied
+				Undoer.FreezeUndo ();
+				foreach (Gtk.TextTag tag in args.StartChar.Tags) {
+					if (!(tag is DepthNoteTag)) {
+						RemoveTag (tag, args.StartChar, args.EndChar);
+					}
+				}
+				Undoer.ThawUndo ();
+			}
+		}
+
 		public bool IsActiveTag (string tag_name)
 		{
 			Gtk.TextTag tag = TagTable.Lookup (tag_name);
 			Gtk.TextIter iter, select_end;
 
-			if (GetSelectionBounds (out iter, out select_end))
+			if (GetSelectionBounds (out iter, out select_end)) {
+				// Ignore the bullet character and look at the
+				// first character of the list item
+				if (FindDepthTag(ref iter) != null)
+					iter.ForwardChars (2);
 				return iter.BeginsTag (tag) || iter.HasTag (tag);
-			else
+			} else {
 				return active_tags.Contains (tag);
+			}
 		}
 		
 		// Returns true if the cursor is inside of a bulleted list
@@ -128,6 +167,19 @@ namespace Tomboy
 			
 			return true;
 		}
+		
+		// Returns true if the cursor is at a position that can
+		// be made into a bulleted list
+		public bool CanMakeBulletedList ()
+		{
+			Gtk.TextMark insert_mark = InsertMark;
+			Gtk.TextIter iter = GetIterAtMark (insert_mark);
+			
+			if (iter.Line == 0)
+				return false;
+			
+			return true;			
+		}
 
 		// Apply active_tags to inserted text
 		void TextInsertedEvent (object sender, Gtk.InsertTextArgs args)
@@ -153,7 +205,10 @@ namespace Tomboy
 		}
 		
 		public bool AddNewline()
-		{			
+		{	
+			if (!CanMakeBulletedList())
+				return false;
+				
 			Gtk.TextMark insert_mark = InsertMark;
 			Gtk.TextIter iter = GetIterAtMark (insert_mark);
 			iter.LineOffset = 0;
@@ -595,20 +650,33 @@ namespace Tomboy
 
 		public void IncreaseCursorDepth ()
 		{
-			Gtk.TextMark insert_mark = InsertMark;
-			Gtk.TextIter insert_iter = GetIterAtMark (insert_mark);
-
-			insert_iter.LineOffset = 0;
-
-			IncreaseDepth (ref insert_iter);
+			ChangeCursorDepth (true);
 		}
 		
 		public void DecreaseCursorDepth ()
 		{
-			Gtk.TextMark insert_mark = InsertMark;
-			Gtk.TextIter insert_iter = GetIterAtMark (insert_mark);
+			ChangeCursorDepth (false);
+		}
+		
+		void ChangeCursorDepth(bool increase)
+		{
+			Gtk.TextIter start;
+			Gtk.TextIter end;
 			
-			DecreaseDepth (ref insert_iter);
+			GetSelectionBounds (out start, out end);
+			
+			Gtk.TextIter curr_line;
+			
+			int start_line = start.Line;
+			int end_line = end.Line;
+			
+			for (int i = start_line; i <= end_line; i++) {
+				curr_line = GetIterAtLine(i);
+				if (increase)
+					IncreaseDepth (ref curr_line);
+				else
+					DecreaseDepth (ref curr_line);
+			}		
 		}
 		
 		public void InsertBullet (ref Gtk.TextIter iter, int depth)
@@ -645,6 +713,9 @@ namespace Tomboy
 		
 		public void IncreaseDepth (ref Gtk.TextIter start)
 		{
+			if (!CanMakeBulletedList())
+				return;
+				
 			Gtk.TextIter end;
 
 			start = GetIterAtLineOffset (start.Line, 0);
@@ -676,6 +747,9 @@ namespace Tomboy
 				
 		public void DecreaseDepth (ref Gtk.TextIter start)
 		{
+			if (!CanMakeBulletedList())
+				return;
+						
 			Gtk.TextIter end;
 
 			start = GetIterAtLineOffset (start.Line, 0);
@@ -930,7 +1004,7 @@ namespace Tomboy
 				bool end_of_depth_line = line_has_depth && next_iter.EndsLine ();
 
 				bool next_line_has_depth = false;
-				if (iter.Line < buffer.LineCount) {
+				if (iter.Line < buffer.LineCount - 1) {
 					Gtk.TextIter next_line = buffer.GetIterAtLine(iter.Line+1);
 					next_line_has_depth =
 						((NoteBuffer)buffer).FindDepthTag(ref next_line) != null;
@@ -996,9 +1070,9 @@ namespace Tomboy
 				if (end_of_depth_line && !next_line_has_depth) {
 					for (int i = prev_depth; i > -1; i--) {
 						// Close <list>
-						xml.WriteEndElement ();
+						xml.WriteFullEndElement ();
 						// Close <list-item>
-						xml.WriteEndElement ();
+						xml.WriteFullEndElement ();
 					}
 							
 					prev_depth = -1;
